pm4py.algo.enhancement.roles.common package
===========================================

Submodules
----------

pm4py.algo.enhancement.roles.common.algorithm module
----------------------------------------------------

.. automodule:: pm4py.algo.enhancement.roles.common.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.enhancement.roles.common
   :members:
   :undoc-members:
   :show-inheritance:
